==> batch_flutter-1.0.0-rc.1.tar.gz: README.md <==
<img src="https://static.batch.com/documentation/Readmes/logo_batch_full_178@2x.png" srcset="https://static.batch.com/documentation/Readmes/logo_batch_full_178.png 1x" width="178" height="68" alt="Batch Logo" />

# Batch Flutter Plugin

The Batch Flutter Plugin allows you to build meaningful communication experience in your iOS app through highly personalized push notifications & In-App messages.

Our [📕 setup documentation](https://flutter-doc-preview.batchers.vercel.app/flutter/prerequisites) details the steps to take for an easy and successful integration.

# Prerequisites
The Batch Flutter Plugin requires Flutter 2 and Dart 2.12 or higher.

As this plugin is built over Batch's Native SDKs, their respective Android and iOS requirements apply.

# Development

<div style="background-color: rgb(255, 253, 237); color: black;">

`batch_flutter` is under development and isn't feature complete yet. 
Publication on pub.dev might not happen until the first release candidate.

Our roadmap is available in [ROADMAP.md](ROADMAP.md).

</div>

# Documentation
- [Setup guide](https://flutter-doc-preview.batchers.vercel.app/flutter/prerequisites): start your implementation here!
- [Help center](https://help.batch.com/en/): answers to most questions you may have during the integration
- [API reference](https://flutter-doc-preview.batchers.vercel.app/flutter-dart-api-reference/index.html): this documents each of the classes and methods in the Batch Flutter Plugin

You may also find this guide useful to review after integration to make sure you're ready to go live: [How can I test the integration on iOS?](https://help.batch.com/en/articles/2669866-how-can-i-test-the-integration-on-ios) / [How can I test the integration on Android?](https://help.batch.com/en/articles/2672749-how-can-i-test-the-integration-on-android)

# Releases
The plugin will eventually be available on pub.dev.
 
# Building

Build instructions are detailed in [BUILDING.md](https://github.com/BatchLabs/Batch-Flutter-Plugin/blob/master/BUILDING.md).

# Contributing
Please refer to our [contributing guidelines](https://github.com/BatchLabs/Batch-Flutter-Plugin/blob/master/CONTRIBUTING.md).

==> batch_flutter-1.4.0.tar.gz: README.md <==
<img src="https://static.batch.com/documentation/Readmes/logo_batch_full_178@2x.png" srcset="https://static.batch.com/documentation/Readmes/logo_batch_full_178.png 1x" width="178" height="68" alt="Batch Logo" />

# Batch Flutter Plugin

The Batch Flutter Plugin allows you to build meaningful communication experience in your iOS app through highly personalized push notifications & In-App messages.

Our [📕 setup documentation](https://flutter-doc-preview.batchers.vercel.app/flutter/prerequisites) details the steps to take for an easy and successful integration.

# Prerequisites
The Batch Flutter Plugin requires Flutter 2 and Dart 2.12 or higher.

As this plugin is built over Batch's Native SDKs, their respective Android and iOS requirements apply.

# Documentation
- [Setup guide](https://doc.batch.com/flutter/prerequisites): start your implementation here!
- [Help center](https://help.batch.com/en/): answers to most questions you may have during the integration
- [API reference](https://doc.batch.com/flutter-dart-api-reference/index.html): this documents each of the classes and methods in the Batch Flutter Plugin

You may also find this guide useful to review after integration to make sure you're ready to go live: [How can I test the integration on iOS?](https://help.batch.com/en/articles/2669866-how-can-i-test-the-integration-on-ios) / [How can I test the integration on Android?](https://help.batch.com/en/articles/2672749-how-can-i-test-the-integration-on-android)

# Releases
The plugin is available on pub.dev.
 
# Building
Build instructions are detailed in [BUILDING.md](https://github.com/BatchLabs/Batch-Flutter-Plugin/blob/master/BUILDING.md).

# Contributing
Please refer to our [contributing guidelines](https://github.com/BatchLabs/Batch-Flutter-Plugin/blob/master/CONTRIBUTING.md).
